@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -462,7 +462,15 @@ void DlgBackup::computeRequiredSpace(void)
 				Q_ASSERT(0);
 				break;
 			}
-			qint64 size = dbSet->dbSize();
+			/*!
+			 * Force access to all databases in the database set.
+			 *
+			 * FIXME - The code doesn't handle simultaneous backup
+			 * and connecting of databases on demand. Forcing the
+			 * databases to be open before backing them up is just
+			 * a workaround which should be fixed properly.
+			 */
+			qint64 size = dbSet->dbSize(true);
 			if (size >= 0) {
 				m_requiredSpace += size;
 			} else {
@@ -532,7 +540,7 @@ void DlgBackup::initDialogue(void)
 
 	m_ui->requiredSpaceLabel->setText(QString());
 	m_ui->accountView->setNarrowedLineHeight();
-	m_ui->accountView->horizontalHeader()->setDefaultAlignment(Qt::AlignLeft);
+	m_ui->accountView->horizontalHeader()->setDefaultAlignment(Qt::AlignVCenter | Qt::AlignLeft);
 	m_ui->accountView->setSelectionMode(QAbstractItemView::ExtendedSelection);
 	m_ui->accountView->setSelectionBehavior(QAbstractItemView::SelectRows);
 
