@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@
 #include "src/global.h"
 #include "src/gui/dlg_correspondence_overview.h"
 #include "src/gui/dlg_msg_box_detail.h"
+#include "src/gui/styles.h"
 #include "src/identifiers/message_id.h"
 #include "src/io/exports.h"
 #include "src/io/filesystem.h"
@@ -80,8 +81,12 @@ DlgCorrespondenceOverview::DlgCorrespondenceOverview(const MessageDbSet &dbSet,
 	m_ui->outputFormatComboBox->addItem(CSV_LITERAL);
 	m_ui->outputFormatComboBox->addItem(HTML_LITERAL);
 
-	connect(m_ui->outputFormatComboBox, SIGNAL(currentIndexChanged(QString)),
-	    this, SLOT(reflectOverviewTypeChange(QString)));
+	/* Days in week and week number format. */
+	GuiStyles::setCalendarStyle(m_ui->fromCalendarWidget);
+	GuiStyles::setCalendarStyle(m_ui->toCalendarWidget);
+
+	connect(m_ui->outputFormatComboBox, SIGNAL(currentIndexChanged(int)),
+	    this, SLOT(reflectOverviewTypeChange(int)));
 
 	connect(m_ui->fromCalendarWidget, SIGNAL(clicked(QDate)),
 	    this, SLOT(reflectCalendarChange()));
@@ -141,9 +146,10 @@ void DlgCorrespondenceOverview::exportData(const MessageDbSet &dbSet,
 	dlg.exportChosenData(acntId, prefs);
 }
 
-void DlgCorrespondenceOverview::reflectOverviewTypeChange(const QString &text)
+void DlgCorrespondenceOverview::reflectOverviewTypeChange(int index)
 {
-	m_ui->groupBox->setEnabled(text == HTML_LITERAL);
+	m_ui->groupBox->setEnabled(
+	    m_ui->outputFormatComboBox->itemText(index) == HTML_LITERAL);
 }
 
 void DlgCorrespondenceOverview::checkMsgTypeSelection(void)
@@ -155,6 +161,7 @@ void DlgCorrespondenceOverview::reflectCalendarChange(void)
 {
 	m_ui->toCalendarWidget->setMinimumDate(
 	    m_ui->fromCalendarWidget->selectedDate());
+	GuiStyles::setCalendarStyle(m_ui->toCalendarWidget);
 
 	updateExportedMsgList(m_ui->fromCalendarWidget->selectedDate(),
 	    m_ui->toCalendarWidget->selectedDate());
@@ -342,11 +349,11 @@ QString DlgCorrespondenceOverview::msgHtmlEntry(const AcntId &acntId,
 	    QStringLiteral("</b></i></td></tr><tr><td>")
 	    + tr("Sender") +
 	    QStringLiteral(":</td><td><i>")
-	    + messageItems.at(0) +
+	    + messageItems.at(0) + " (" + messageItems.at(5) + ")" +
 	    QStringLiteral("</i></td></tr><tr><td>")
 	    + tr("Recipient") +
 	    QStringLiteral(":</td><td><i>")
-	    + messageItems.at(1) +
+	    + messageItems.at(1) + " (" + messageItems.at(6) + ")" +
 	    QStringLiteral("</i></td></tr></table></td></tr></table>"));
 	if (m_ui->addTagsCheckBox->checkState() == Qt::Checked) {
 		retStr += tagHtmlEntry(m_tagCont, acntId, mId.dmId(),
@@ -387,7 +394,9 @@ bool DlgCorrespondenceOverview::writeCsvOverview(const QString &fileName) const
 	    tr("Sender file mark") + QStringLiteral(",") +
 	    tr("Sender reference number") + QStringLiteral(",") +
 	    tr("Recipient file mark") + QStringLiteral(",") +
-	    tr("Recipient reference number") + QStringLiteral("\n");
+	    tr("Recipient reference number") + QStringLiteral(",") +
+	    tr("Sender data-box ID") + QStringLiteral(",") +
+	    tr("Recipient data-box ID") + QStringLiteral("\n");
 
 	/* Sent messages. */
 	if (m_ui->sentCheckBox->isChecked()) {
@@ -625,7 +634,7 @@ int exportMessageData(const QList<MsgId> &mIds, QWidget *parent,
 	    GlobInstcs::acntMapPtr->acntData(acntId).accountName());
 
 	foreach (const MsgId &mId, mIds) {
-		ret = Exports::exportAs(parent, dbSet, fileType, targetPath,
+		ret = Exports::exportAsGUI(parent, dbSet, fileType, targetPath,
 		    QString(), acntId.username(), accountName, dbId, mId, false,
 		    lastPath, errStr);
 		if (Exports::EXP_SUCCESS == ret) {
