@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@
 
 #include <algorithm> /* ::std::sort */
 #include <QMenuBar>
-#include <QSet>
 #include <QToolBar>
 
 #include "src/datovka_shared/compat/compiler.h" /* ignoreRetVal */
@@ -33,6 +32,7 @@
 #include "src/global.h"
 #include "src/gui/dlg_tool_bar.h"
 #include "src/gui/icon_container.h"
+#include "src/gui/styles.h"
 #include "src/json/action_entry.h"
 #include "src/model_interaction/view_interaction.h"
 #include "src/models/sort_filter_proxy_model.h"
@@ -44,16 +44,118 @@
 #define MAIN_TOP_TOOLBAR_STYLE_KEY "window.main.toolbar.button.style"
 #define MAIN_TOP_TOOLBAR_CONTENT_KEY "window.main.toolbar.content"
 
+#define MAIN_ACCOUNT_TOOLBAR_STYLE_KEY "window.main.account.toolbar.button.style"
+#define MAIN_ACCOUNT_TOOLBAR_CONTENT_KEY "window.main.account.toolbar.content"
+
+#define MAIN_MESSAGE_TOOLBAR_STYLE_KEY "window.main.message.toolbar.button.style"
+#define MAIN_MESSAGE_TOOLBAR_CONTENT_KEY "window.main.message.toolbar.content"
+
+#define MAIN_DETAIL_TOOLBAR_STYLE_KEY "window.main.detail.toolbar.button.style"
+#define MAIN_DETAIL_TOOLBAR_CONTENT_KEY "window.main.detail.toolbar.content"
+
+#define MAIN_ATTACHMENT_TOOLBAR_STYLE_KEY "window.main.attachment.toolbar.button.style"
+#define MAIN_ATTACHMENT_TOOLBAR_CONTENT_KEY "window.main.attachment.toolbar.content"
+
 #define VAL_ALL -1
 
+/*!
+ * @brief Return default tool bar button style for given tool bar position.
+ *
+ * @param[in] position Tool bar position.
+ * @return Too-bar button style.
+ */
+static
+enum PrefsSpecific::ToolbarButtonStyle dfltButtonStyle(
+    enum DlgToolBar::Position position)
+{
+	switch (position) {
+	case DlgToolBar::MAIN_TOP:
+		return PrefsSpecific::TEXT_UNDER_ICON;
+		break;
+	case DlgToolBar::ACCOUNT:
+	case DlgToolBar::MESSAGE:
+	case DlgToolBar::DETAIL:
+	case DlgToolBar::ATTACHMENT:
+		return PrefsSpecific::ICON_ONLY;
+		break;
+	default:
+		return PrefsSpecific::TEXT_UNDER_ICON;
+		break;
+	}
+}
+
+/*!
+ * @brief Return preferences key for style setting for given tool bar.
+ *
+ * @param[in] position Tool bar position.
+ * @return Style setting key.
+ */
+static
+const char *toolbarStyleKey(enum DlgToolBar::Position position)
+{
+	switch (position) {
+	case DlgToolBar::MAIN_TOP:
+		return MAIN_TOP_TOOLBAR_STYLE_KEY;
+		break;
+	case DlgToolBar::ACCOUNT:
+		return MAIN_ACCOUNT_TOOLBAR_STYLE_KEY;
+		break;
+	case DlgToolBar::MESSAGE:
+		return MAIN_MESSAGE_TOOLBAR_STYLE_KEY;
+		break;
+	case DlgToolBar::DETAIL:
+		return MAIN_DETAIL_TOOLBAR_STYLE_KEY;
+		break;
+	case DlgToolBar::ATTACHMENT:
+		return MAIN_ATTACHMENT_TOOLBAR_STYLE_KEY;
+		break;
+	default:
+		return MAIN_TOP_TOOLBAR_STYLE_KEY;
+		break;
+	}
+}
+
+/*!
+ * @brief Return preferences key for content setting for given tool bar.
+ *
+ * @param[in] position Tool bar position.
+ * @return Content setting key.
+ */
+static
+const char *toolbarContentKey(enum DlgToolBar::Position position)
+{
+	switch (position) {
+	case DlgToolBar::MAIN_TOP:
+		return MAIN_TOP_TOOLBAR_CONTENT_KEY;
+		break;
+	case DlgToolBar::ACCOUNT:
+		return MAIN_ACCOUNT_TOOLBAR_CONTENT_KEY;
+		break;
+	case DlgToolBar::MESSAGE:
+		return MAIN_MESSAGE_TOOLBAR_CONTENT_KEY;
+		break;
+	case DlgToolBar::DETAIL:
+		return MAIN_DETAIL_TOOLBAR_CONTENT_KEY;
+		break;
+	case DlgToolBar::ATTACHMENT:
+		return MAIN_ATTACHMENT_TOOLBAR_CONTENT_KEY;
+		break;
+	default:
+		return MAIN_TOP_TOOLBAR_CONTENT_KEY;
+		break;
+	}
+}
+
 /*!
  * @brief Convert menu actions into model entries.
  *
  * @param[in] menu Menu bar for actions.
+ * @param[in] excluded Ignored actions.
  * @return Menu action list.
  */
 static
-QList<ActionListModel::Entry> constructEntriesFromMenu(const QMenu *menu)
+QList<ActionListModel::Entry> constructEntriesFromMenu(const QMenu *menu,
+    const QSet<QAction *> &excluded)
 {
 	QList<ActionListModel::Entry> entryList;
 
@@ -72,13 +174,15 @@ QList<ActionListModel::Entry> constructEntriesFromMenu(const QMenu *menu)
 		{
 			QMenu *menu = action->menu();
 			if (menu != Q_NULLPTR) {
-				entryList.append(constructEntriesFromMenu(menu));
+				entryList.append(constructEntriesFromMenu(menu, excluded));
 				continue;
 			}
 		}
 		{
-			entryList.append(ActionListModel::Entry(
-			    ActionListModel::Entry::TYPE_ACTION, false, action));
+			if (!excluded.contains(action)) {
+				entryList.append(ActionListModel::Entry(
+				    ActionListModel::Entry::TYPE_ACTION, false, action));
+			}
 		}
 	}
 
@@ -92,13 +196,14 @@ QList<ActionListModel::Entry> constructEntriesFromMenu(const QMenu *menu)
  * @return Stored action list.
  */
 static
-Json::ActionEntryList loadStoredList(bool *ok = Q_NULLPTR)
+Json::ActionEntryList loadStoredList(enum DlgToolBar::Position position,
+    bool *ok = Q_NULLPTR)
 {
 	bool iOk = false;
 	Json::ActionEntryList storedList;
 
 	QString val;
-	if (Q_UNLIKELY(!GlobInstcs::prefsPtr->strVal(MAIN_TOP_TOOLBAR_CONTENT_KEY, val))) {
+	if (Q_UNLIKELY(!GlobInstcs::prefsPtr->strVal(toolbarContentKey(position), val))) {
 		goto fail;
 	}
 	if (val.isEmpty()) {
@@ -122,12 +227,14 @@ fail:
  * @brief Construct model entries from tool bar.
  *
  * @param[in] toolBar Tool bar to scan for actions.
- * @param[in] firstUnconfigurableToolbarElement First init action.
+ * @param[in] afterUnconfigurableToolbarElement Tool bar action after which to start.
+ * @param[in] beforeUnconfigurableToolbarElement Tool bar action before which to stop.
  * @return List of model action entries.
  */
 static
 QList<ActionListModel::Entry> constructEntriesFromToolBar(const QToolBar *toolBar,
-    QAction *firstUnconfigurableToolbarElement)
+    QAction *afterUnconfigurableToolbarElement,
+    QAction *beforeUnconfigurableToolbarElement)
 {
 	QList<ActionListModel::Entry> entryList;
 
@@ -136,17 +243,32 @@ QList<ActionListModel::Entry> constructEntriesFromToolBar(const QToolBar *toolBa
 		return entryList;
 	}
 
+	bool collect = (Q_NULLPTR == afterUnconfigurableToolbarElement);
+
 	for (QAction *action : toolBar->actions()) {
 		if (Q_UNLIKELY(action == Q_NULLPTR)) {
 			continue;
 		}
-		if (action == firstUnconfigurableToolbarElement) {
-			/* Non-null and equal. */
+		if (action == afterUnconfigurableToolbarElement) {
+			/*
+			 * Non-null and equal.
+			 * Start collecting from next action.
+			 */
+			collect = true;
+			continue;
+		}
+		if (action == beforeUnconfigurableToolbarElement) {
+			/*
+			 * Non-null and equal.
+			 * Stop collecting.
+			 */
 			break;
 		}
 
-		entryList.append(ActionListModel::Entry(
-		    ActionListModel::Entry::TYPE_ACTION, true, action));
+		if (collect) {
+			entryList.append(ActionListModel::Entry(
+			    ActionListModel::Entry::TYPE_ACTION, true, action));
+		}
 	}
 
 	return entryList;
@@ -158,26 +280,31 @@ QList<ActionListModel::Entry> constructEntriesFromToolBar(const QToolBar *toolBa
  * @note May contain unchecked values.
  *
  * @param[in] availableMenus List of available menus, containing actions.
+ * @param[in] excluded Ignored actions.
  * @param[in] toolBar Tool bar to scan for actions.
- * @param[in] firstUnconfigurableToolbarElement Tool bar action before which to stop.
+ * @param[in] afterUnconfigurableToolbarElement Tool bar action after which to start.
+ * @param[in] beforeUnconfigurableToolbarElement Tool bar action before which to stop.
  * @return List of model action entries.
  */
 static
 QList<ActionListModel::Entry> constructStoredEntries(
-    const QList<QMenu *> &availableMenus, const QToolBar *toolBar,
-    QAction *firstUnconfigurableToolbarElement)
+    const QList<QMenu *> &availableMenus, const QSet<QAction *> &excluded,
+    enum DlgToolBar::Position position,
+    const QToolBar *toolBar, QAction *afterUnconfigurableToolbarElement,
+    QAction *beforeUnconfigurableToolbarElement)
 {
 	QList<ActionListModel::Entry> availableEntries;
 	QList<ActionListModel::Entry> toolBarEntries =
-	    constructEntriesFromToolBar(toolBar, firstUnconfigurableToolbarElement);
+	    constructEntriesFromToolBar(toolBar, afterUnconfigurableToolbarElement,
+	        beforeUnconfigurableToolbarElement);
 	QList<ActionListModel::Entry> constructedEntryList;
 	{
 		for (const QMenu *menu : availableMenus) {
-			availableEntries.append(constructEntriesFromMenu(menu));
+			availableEntries.append(constructEntriesFromMenu(menu, excluded));
 		}
 	}
 	bool iOk = false;
-	Json::ActionEntryList storedList = loadStoredList(&iOk);
+	Json::ActionEntryList storedList = loadStoredList(position, &iOk);
 	if (Q_UNLIKELY(!iOk)) {
 		goto fail;
 	}
@@ -265,12 +392,14 @@ fail:
  * @brief Construct actions from tool bar.
  *
  * @param[in] toolBar Tool bar to scan for actions.
- * @param[in] firstUnconfigurableToolbarElement First init action.
+ * @param[in] afterUnconfigurableToolbarElement Tool bar action after which to start.
+ * @param[in] beforeUnconfigurableToolbarElement Tool bar action before which to stop.
  * @return List of actions.
  */
 static
 QList<QAction *> conctructActions(const QToolBar *toolBar,
-    QAction *firstUnconfigurableToolbarElement)
+    QAction *afterUnconfigurableToolbarElement,
+    QAction *beforeUnconfigurableToolbarElement)
 {
 	QList<QAction *> actionList;
 
@@ -279,29 +408,50 @@ QList<QAction *> conctructActions(const QToolBar *toolBar,
 		return actionList;
 	}
 
+	bool collect = (Q_NULLPTR == afterUnconfigurableToolbarElement);
+
 	for (QAction *action : toolBar->actions()) {
 		if (Q_UNLIKELY(action == Q_NULLPTR)) {
 			continue;
 		}
-		if (action == firstUnconfigurableToolbarElement) {
-			/* Non-null and equal. */
+		if (action == afterUnconfigurableToolbarElement) {
+			/*
+			 * Non-null and equal.
+			 * Start collecting from next action.
+			 */
+			collect = true;
+			continue;
+		}
+		if (action == beforeUnconfigurableToolbarElement) {
+			/*
+			 * Non-null and equal.
+			 * Stop collecting.
+			 */
 			break;
 		}
 
-		actionList.append((!action->isSeparator()) ? action : Q_NULLPTR);
+		if (collect) {
+			actionList.append((!action->isSeparator()) ? action : Q_NULLPTR);
+		}
 	}
 
 	return actionList;
 }
 
-DlgToolBar::DlgToolBar(QMenuBar *menuBar,  QToolBar *toolBar,
-    QAction *firstUnconfigurableToolbarElement,
+DlgToolBar::DlgToolBar(const QMenuBar *menuBar,
+    const QList<QAction *> &unlistedInMenu, const QSet<QAction *> &excluded,
+    enum Position position,
+    QToolBar *toolBar, QAction *afterUnconfigurableToolbarElement,
+    QAction *beforeUnconfigurableToolbarElement,
     const QList<QAction *> &defaultToolBarActions, QWidget *parent)
     : QDialog(parent),
     m_ui(new (::std::nothrow) Ui::DlgToolBar),
-    m_menuBar(menuBar),
+    m_dummyMenu(tr("Commands Unlisted in Top Menu"), this),
+    m_excludedActions(excluded),
+    m_position(position),
     m_toolBar(toolBar),
-    m_firstUnconfigurableToolbarElement(firstUnconfigurableToolbarElement),
+    m_afterUnconfigurableToolbarElement(afterUnconfigurableToolbarElement),
+    m_beforeUnconfigurableToolbarElement(beforeUnconfigurableToolbarElement),
     m_defaultToolBarActions(defaultToolBarActions),
     m_availableMenuModel(this),
     m_availableMenus(),
@@ -315,10 +465,10 @@ DlgToolBar::DlgToolBar(QMenuBar *menuBar,  QToolBar *toolBar,
 	initDlg();
 
 	/* Read menu bar menus and actions. */
-	if (m_menuBar != Q_NULLPTR) {
-		m_availableMenuModel.appendRow(tr("All commands"), VAL_ALL, true);
+	if (menuBar != Q_NULLPTR) {
+		m_availableMenuModel.appendRow(tr("All Commands"), VAL_ALL, true);
 
-		for (QAction *action : m_menuBar->actions()) {
+		for (QAction *action : menuBar->actions()) {
 			if (Q_UNLIKELY(action == Q_NULLPTR)) {
 				continue;
 			}
@@ -337,34 +487,52 @@ DlgToolBar::DlgToolBar(QMenuBar *menuBar,  QToolBar *toolBar,
 		}
 	}
 
+	/* Fill a dummy menu with addtional actions. */
+	if (!unlistedInMenu.isEmpty()) {
+		QMenu *menu = &m_dummyMenu;
+		for (QAction *action : unlistedInMenu) {
+			if (Q_NULLPTR != action) {
+				menu->addAction(action);
+			}
+		}
+
+		{
+			m_availableMenuModel.appendRow(
+			    menu->title(),
+			    m_availableMenus.size(), true);
+			m_availableMenus.append(menu);
+		}
+	}
+
 	/* Load operations. */
 	loadAvailableOperations(m_ui->categoryComboBox->currentIndex());
 
 	/* Load button style. */
 	{
-		qint64 val = PrefsSpecific::TEXT_UNDER_ICON;
-		if (GlobInstcs::prefsPtr->intVal(MAIN_TOP_TOOLBAR_STYLE_KEY, val)) {
-			switch (val) {
-			case PrefsSpecific::ICON_ONLY:
-				m_ui->iconOnlyRadio->setChecked(true);
-				break;
-			case PrefsSpecific::TEXT_BESIDE_ICON:
-				m_ui->textBesideIconRadio->setChecked(true);
-				break;
-			case PrefsSpecific::TEXT_UNDER_ICON:
-				m_ui->textUnderIconRadio->setChecked(true);
-				break;
-			default:
-				Q_ASSERT(0);
-				break;
-			}
+		qint64 val = dfltButtonStyle(m_position);
+		ignoreRetVal(GlobInstcs::prefsPtr->intVal(toolbarStyleKey(m_position), val));
+		switch (val) {
+		case PrefsSpecific::ICON_ONLY:
+			m_ui->iconOnlyRadio->setChecked(true);
+			break;
+		case PrefsSpecific::TEXT_BESIDE_ICON:
+			m_ui->textBesideIconRadio->setChecked(true);
+			break;
+		case PrefsSpecific::TEXT_UNDER_ICON:
+			m_ui->textUnderIconRadio->setChecked(true);
+			break;
+		default:
+			Q_ASSERT(0);
+			break;
 		}
 	}
 
 	if (m_toolBar != Q_NULLPTR) {
 		m_assignedOperationsModel.insertActions(
-		    constructStoredEntries(m_availableMenus, m_toolBar,
-		        m_firstUnconfigurableToolbarElement));
+		    constructStoredEntries(m_availableMenus, m_excludedActions,
+		        m_position,
+		        m_toolBar, m_afterUnconfigurableToolbarElement,
+		        m_beforeUnconfigurableToolbarElement));
 	}
 }
 
@@ -459,23 +627,28 @@ Json::ActionEntryList actionList2Json(const QList<QAction *> actions)
 }
 
 /*!
- * @brief Remove actions from tool bar before given action.
+ * @brief Remove actions from tool bar after and before given actions.
  *
  * @param[in] toolBar Tool bar to to remove actions from.
- * @param[in] befire Action before which to remove.
+ * @param[in] after Action after which to remove.
+ * @param[in] before Action before which to remove.
  */
 static
-void removeToolBarActions(QToolBar *toolBar, QAction *before = Q_NULLPTR)
+void removeToolBarActions(QToolBar *toolBar, QAction *after, QAction *before)
 {
 	if (Q_UNLIKELY(toolBar == Q_NULLPTR)) {
 		Q_ASSERT(0);
 		return;
 	}
 
+	bool remove = (Q_NULLPTR == after);
+
 	for (QAction *action : toolBar->actions()) {
-		if (action != before) {
+		if ((Q_NULLPTR != after) && (action == after)) {
+			remove = true;
+		} else if (remove && (action != before)) {
 			toolBar->removeAction(action);
-		} else {
+		} else if (action == before) {
 			return;
 		}
 	}
@@ -507,8 +680,11 @@ Qt::ToolButtonStyle qtToolButtonStyle(int style)
 	}
 }
 
-bool DlgToolBar::configureToolBar(QMenuBar *menuBar,  QToolBar *toolBar,
-    QAction *firstUnconfigurableToolbarElement,
+bool DlgToolBar::configureToolBar(const QMenuBar *menuBar,
+    const QList<QAction *> &unlistedInMenu, const QSet<QAction *> &excluded,
+    enum Position position,
+    QToolBar *toolBar, QAction *afterUnconfigurableToolbarElement,
+    QAction *beforeUnconfigurableToolbarElement,
     const QList<QAction *> &defaultToolBarActions, QWidget *parent)
 {
 	if (Q_UNLIKELY(menuBar == Q_NULLPTR)) {
@@ -519,13 +695,15 @@ bool DlgToolBar::configureToolBar(QMenuBar *menuBar,  QToolBar *toolBar,
 	QList<QAction *> startToolBarActions;
 	if (toolBar != Q_NULLPTR) {
 		startToolBarActions = conctructActions(toolBar,
-		    firstUnconfigurableToolbarElement);
+		    afterUnconfigurableToolbarElement,
+		    beforeUnconfigurableToolbarElement);
 	}
 	enum PrefsSpecific::ToolbarButtonStyle startButtonStyle =
-	    (enum PrefsSpecific::ToolbarButtonStyle)toolBarButtonStyle();
+	    (enum PrefsSpecific::ToolbarButtonStyle)toolBarButtonStyle(position);
 
-	DlgToolBar dlg(menuBar, toolBar, firstUnconfigurableToolbarElement,
-	    defaultToolBarActions, parent);
+	DlgToolBar dlg(menuBar, unlistedInMenu, excluded, position, toolBar,
+	    afterUnconfigurableToolbarElement,
+	    beforeUnconfigurableToolbarElement, defaultToolBarActions, parent);
 
 	const QString dlgName("tool_bar");
 	const QSize dfltSize = dlg.size();
@@ -551,16 +729,16 @@ bool DlgToolBar::configureToolBar(QMenuBar *menuBar,  QToolBar *toolBar,
 		    actionEntryListModel2Json(dlg.m_assignedOperationsModel.entries());
 
 		if (defaultList != actualList) {
-			GlobInstcs::prefsPtr->setStrVal(MAIN_TOP_TOOLBAR_CONTENT_KEY,
+			GlobInstcs::prefsPtr->setStrVal(toolbarContentKey(position),
 			    actualList.toJsonData());
 		} else {
 			/* Erase entry. */
-			GlobInstcs::prefsPtr->resetVal(MAIN_TOP_TOOLBAR_CONTENT_KEY);
+			GlobInstcs::prefsPtr->resetVal(toolbarContentKey(position));
 		}
 
 		/* Save button style. */
 		{
-			qint64 val = PrefsSpecific::TEXT_UNDER_ICON;
+			qint64 val = dfltButtonStyle(position);
 			if (dlg.m_ui->iconOnlyRadio->isChecked()) {
 				val = PrefsSpecific::ICON_ONLY;
 			} else if (dlg.m_ui->textBesideIconRadio->isChecked()) {
@@ -568,16 +746,17 @@ bool DlgToolBar::configureToolBar(QMenuBar *menuBar,  QToolBar *toolBar,
 			} else if (dlg.m_ui->textUnderIconRadio->isChecked()) {
 				val = PrefsSpecific::TEXT_UNDER_ICON;
 			}
-			GlobInstcs::prefsPtr->setIntVal(MAIN_TOP_TOOLBAR_STYLE_KEY, val);
+			GlobInstcs::prefsPtr->setIntVal(toolbarStyleKey(position), val);
 		}
 	} else {
 		/* Restore content at start. */
 		if (toolBar != Q_NULLPTR) {
 			removeToolBarActions(toolBar,
-			    firstUnconfigurableToolbarElement);
+			    afterUnconfigurableToolbarElement,
+			    beforeUnconfigurableToolbarElement);
 
 			insertToolBarActions(toolBar, startToolBarActions,
-			    firstUnconfigurableToolbarElement);
+			    beforeUnconfigurableToolbarElement);
 
 			toolBar->setToolButtonStyle(
 			    qtToolButtonStyle(startButtonStyle));
@@ -624,7 +803,7 @@ void DlgToolBar::loadAvailableOperations(int availableMenuIndex)
 	if (value == VAL_ALL) {
 		for (const QMenu *menu : m_availableMenus) {
 			m_availableOperationsModel.insertActions(
-			    constructEntriesFromMenu(menu));
+			    constructEntriesFromMenu(menu, m_excludedActions));
 		}
 	} else {
 		if (value >= m_availableMenus.size()) {
@@ -632,7 +811,7 @@ void DlgToolBar::loadAvailableOperations(int availableMenuIndex)
 			return;
 		}
 		m_availableOperationsModel.insertActions(
-		    constructEntriesFromMenu(m_availableMenus.at(value)));
+		    constructEntriesFromMenu(m_availableMenus.at(value), m_excludedActions));
 	}
 
 	m_availableOperationsProxyModel.sort(ActionListModel::COL_ACTION_NAME,
@@ -832,10 +1011,10 @@ void DlgToolBar::assignSelectedAvailableOperations(void)
 
 	if (m_toolBar != Q_NULLPTR) {
 		/* Find position in tool bar. */
-		QAction *before = m_firstUnconfigurableToolbarElement;
+		QAction *before = m_beforeUnconfigurableToolbarElement;
 		if (lastRow != -1) {
 			before = activeAssignedActionFromPosition(lastRow + 1,
-			    m_assignedOperationsModel, m_firstUnconfigurableToolbarElement);
+			    m_assignedOperationsModel, m_beforeUnconfigurableToolbarElement);
 		}
 		/* Insert entries. */
 		for (const ActionListModel::Entry &entry : entries) {
@@ -943,7 +1122,7 @@ void DlgToolBar::handleAssignedDataChange(const QModelIndex &topLeft,
 			} else {
 				/* Insert checked to tool bar. */
 				QAction *before = activeAssignedActionFromPosition(row + 1,
-				    m_assignedOperationsModel, m_firstUnconfigurableToolbarElement);
+				    m_assignedOperationsModel, m_beforeUnconfigurableToolbarElement);
 				insertToolBarAction(m_toolBar, before, action);
 			}
 		}
@@ -966,7 +1145,7 @@ void DlgToolBar::assignedRowsMoved(const QModelIndex &parent, int start, int end
 	const int newStart = (start < row) ? (row - cnt) : row;
 
 	QAction *before = activeAssignedActionFromPosition(newStart + cnt,
-	    m_assignedOperationsModel, m_firstUnconfigurableToolbarElement);
+	    m_assignedOperationsModel, m_beforeUnconfigurableToolbarElement);
 
 	/* Remove and newly insert moved actions. */
 	for (int i = newStart; i < (newStart + cnt); ++i) {
@@ -1135,10 +1314,10 @@ void DlgToolBar::insertSeparator(void)
 
 	if (m_toolBar != Q_NULLPTR) {
 		/* Find position in tool bar. */
-		QAction *before = m_firstUnconfigurableToolbarElement;
+		QAction *before = m_beforeUnconfigurableToolbarElement;
 		if (lastRow != -1) {
 			before = activeAssignedActionFromPosition(lastRow + 1,
-			    m_assignedOperationsModel, m_firstUnconfigurableToolbarElement);
+			    m_assignedOperationsModel, m_beforeUnconfigurableToolbarElement);
 		}
 		/* Create the separator. */
 		QAction *action = m_toolBar->insertSeparator(before);
@@ -1158,7 +1337,9 @@ void DlgToolBar::insertSeparator(void)
 void DlgToolBar::resetDefaults(void)
 {
 	if (m_toolBar != Q_NULLPTR) {
-		removeToolBarActions(m_toolBar, m_firstUnconfigurableToolbarElement);
+		removeToolBarActions(m_toolBar,
+		    m_afterUnconfigurableToolbarElement,
+		    m_beforeUnconfigurableToolbarElement);
 	}
 
 	m_assignedOperationsModel.removeAllRows();
@@ -1166,7 +1347,7 @@ void DlgToolBar::resetDefaults(void)
 	for (QAction *action : m_defaultToolBarActions) {
 		if (action != Q_NULLPTR) {
 			if (m_toolBar != Q_NULLPTR) {
-				insertToolBarAction(m_toolBar, m_firstUnconfigurableToolbarElement, action);
+				insertToolBarAction(m_toolBar, m_beforeUnconfigurableToolbarElement, action);
 			}
 			m_assignedOperationsModel.insertAction(ActionListModel::Entry(ActionListModel::Entry::TYPE_ACTION, true, action));
 		} else {
@@ -1174,7 +1355,23 @@ void DlgToolBar::resetDefaults(void)
 		}
 	}
 
-	m_ui->textUnderIconRadio->setChecked(true);
+	{
+		qint64 val = dfltButtonStyle(m_position);
+		switch (val) {
+		case PrefsSpecific::ICON_ONLY:
+			m_ui->iconOnlyRadio->setChecked(true);
+			break;
+		case PrefsSpecific::TEXT_BESIDE_ICON:
+			m_ui->textBesideIconRadio->setChecked(true);
+			break;
+		case PrefsSpecific::TEXT_UNDER_ICON:
+			m_ui->textUnderIconRadio->setChecked(true);
+			break;
+		default:
+			Q_ASSERT(0);
+			break;
+		}
+	}
 }
 
 void DlgToolBar::initDlg(void)
@@ -1282,17 +1479,17 @@ void DlgToolBar::initDlg(void)
 
 void DlgToolBar::setIcons(void)
 {
-	m_ui->assignButton->setIcon(
-	    IconContainer::construcIcon(IconContainer::ICON_RIGHT));
-
-	m_ui->removeButton->setIcon(
-	    IconContainer::construcIcon(IconContainer::ICON_LEFT));
-
-	m_ui->upButton->setIcon(
-	    IconContainer::construcIcon(IconContainer::ICON_UP));
-
-	m_ui->downButton->setIcon(
-	    IconContainer::construcIcon(IconContainer::ICON_DOWN));
+	if (GuiStyles::intToAppUiTheme(PrefsSpecific::appUiTheme(*GlobInstcs::prefsPtr)) == GuiStyles::NO_THEME) {
+		m_ui->assignButton->setIcon(IconContainer::construcIcon(IconContainer::ICON_APP_ARROW_RIGHT));
+		m_ui->removeButton->setIcon(IconContainer::construcIcon(IconContainer::ICON_APP_ARROW_LEFT));
+		m_ui->upButton->setIcon(IconContainer::construcIcon(IconContainer::ICON_APP_ARROW_UP));
+		m_ui->downButton->setIcon(IconContainer::construcIcon(IconContainer::ICON_APP_ARROW_DOWN));
+	} else {
+		m_ui->assignButton->setIcon(IconContainer::construcIcon(IconContainer::ICON_APP_ARROW_RIGHT_WHITE));
+		m_ui->removeButton->setIcon(IconContainer::construcIcon(IconContainer::ICON_APP_ARROW_LEFT_WHITE));
+		m_ui->upButton->setIcon(IconContainer::construcIcon(IconContainer::ICON_APP_ARROW_UP_WHITE));
+		m_ui->downButton->setIcon(IconContainer::construcIcon(IconContainer::ICON_APP_ARROW_DOWN_WHITE));
+	}
 }
 
 void DlgToolBar::removeSelectedAssignedOperationsViaFilter(QObject *dlgPtr)
@@ -1379,7 +1576,8 @@ QList<QAction *> findActions(const QObject *parent,
 	return actions;
 }
 
-void loadToolBarActions(QObject *actionParent, QToolBar *toolBar,
+void loadToolBarActions(QObject *actionParent,
+    enum DlgToolBar::Position position, QToolBar *toolBar,
     const QList<QAction *> &dfltActionList, QAction *before)
 {
 	if (Q_UNLIKELY(toolBar == Q_NULLPTR)) {
@@ -1389,7 +1587,7 @@ void loadToolBarActions(QObject *actionParent, QToolBar *toolBar,
 
 	bool iOk = false;
 	QList<QAction *> actionList;
-	Json::ActionEntryList storedList = loadStoredList(&iOk);
+	Json::ActionEntryList storedList = loadStoredList(position, &iOk);
 	if (Q_UNLIKELY(!iOk)) {
 		goto fail;
 	}
@@ -1408,10 +1606,10 @@ fail:
 	insertToolBarActions(toolBar, dfltActionList, before);
 }
 
-Qt::ToolButtonStyle toolBarButtonStyle(void)
+Qt::ToolButtonStyle toolBarButtonStyle(enum DlgToolBar::Position position)
 {
-	qint64 val = PrefsSpecific::TEXT_UNDER_ICON;
+	qint64 val = dfltButtonStyle(position);
 	ignoreRetVal(
-	    GlobInstcs::prefsPtr->intVal(MAIN_TOP_TOOLBAR_STYLE_KEY, val));
+	    GlobInstcs::prefsPtr->intVal(toolbarStyleKey(position), val));
 	return qtToolButtonStyle(val);
 }
