@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -359,45 +359,12 @@ public:
 	QDateTime messageAcceptanceTime(qint64 dmId);
 
 	/*!
-	 * @brief Return HTML formatted message description.
+	 * @brief Get Html info about message signature and timestamp.
 	 *
 	 * @param[in] dmId Message identifier.
-	 * @param[in] topInsertedLine A line of HTML text to inserted at the top.
-	 * @param[in] verSignature Whether to show verification details.
-	 * @return HTML formatted string containing message information.
-	 *         Empty string is returned on error.
+	 * @return Html info about message signature and timestamp.
 	 */
-	QString descriptionHtml(qint64 dmId,
-	    const QString &topInsertedLine = QString(), bool verSignature = true);
-
-	/*!
-	 * @brief Return message envelope HTML to be used to generate a PDF.
-	 *
-	 * @param[in] dmId    Message identifier.
-	 * @param[in] dbType  Data-box type string.
-	 * @return HTML formatted string generated from message envelope.
-	 *     Empty string is returned on error.
-	 */
-	QString envelopeInfoHtmlToPdf(qint64 dmId, const QString &dbType);
-
-	/*!
-	 * @brief Return message file list HTML to be used to generate a PDF.
-	 *
-	 * @param[in] dmId    Message identifier.
-	 * @return HTML formatted string generated from message file db.
-	 *     Empty string is returned on error.
-	 */
-	QString fileListHtmlToPdf(qint64 dmId);
-
-	/*!
-	 * @brief Return message delivery info HTML to be used to generate
-	 *     a PDF.
-	 *
-	 * @paramp[in] dmId  Message identifier.
-	 * @return HTML formatted string generated from message delivery
-	 *     information. Empty string is returned on error.
-	 */
-	QString deliveryInfoHtmlToPdf(qint64 dmId);
+	QString verifySignatureHtml(qint64 dmId);
 
 	/*!
 	 * @brief Return attachments related to given message.
@@ -699,6 +666,14 @@ public:
 	bool copyRelevantMsgsToNewDb(const QString &newDbFileName,
 	   const QString &year, bool transaction);
 
+	/*!
+	 * @brief Return message author data in JSON format.
+	 *
+	 * @param[in] dmId Message identifier.
+	 * @return Message author JSON data.
+	 */
+	QByteArray messageAuthorJsonStr(qint64 dmId);
+
 protected: /* These function are used from within a database container. */
 
 	/*!
@@ -912,7 +887,7 @@ protected: /* These function are used from within a database container. */
 	 * @brief Return contacts from message db.
 	 *
 	 * @return List of vectors containing recipientId, recipientName,
-	 *     recipentAddress.
+	 *     recipientAddress.
 	 */
 	QList<ContactEntry> uniqueContacts(void);
 
@@ -958,11 +933,13 @@ protected: /* These function are used from within a database container. */
 	 * @param[in] attachPhrase Phrase to search in attachment names.
 	 * @param[in] logicalAnd Set to true if found messages should match all criteria,
 	 *                       set to false if found messages should match any criteria.
+	 * @param[in] fromDate Start date. Use invalid value to ignore this limit.
+	 * @param[in] toDate Stop date. Use invalid value to ignore this limit.
 	 * @return Found message data.
 	 */
 	QList<SoughtMsg> msgsSearch(const Isds::Envelope &envel,
 	    enum MessageDirection msgDirect, const QString &attachPhrase,
-	    bool logicalAnd);
+	    bool logicalAnd, const QDate &fromDate, const QDate &toDate);
 
 	/*!
 	 * @brief Get message envelope data from id.
@@ -1063,13 +1040,6 @@ public:
 	const QVector<QString> fileItemIds;
 
 private:
-	static
-	const QVector<QString> msgPrintedAttribs;
-	static
-	const QVector<QString> msgDeliveryBoolAttribs;
-	static
-	const QVector<QString> msgStatus;
-
 	/*!
 	 * @brief Returns verification date (in local time).
 	 *
